@@ -2,7 +2,7 @@ package Panda::Config::Perl;
 use 5.012;
 use Panda::Lib(); # XS code needs xs::lib::merge
 
-our $VERSION = '1.1.2';
+our $VERSION = '1.1.3';
 
 require Panda::XSLoader;
 Panda::XSLoader::load();
@@ -57,11 +57,10 @@ sub _process_file {
     my $ok;
     {
         no strict;
+        enable_op_tracking();
         my $sub = eval $content;
-        if ($sub) {
-            tune_ops($sub);
-            $ok = eval { $sub->(); 1 };
-        }
+        disable_op_tracking();
+        $ok = eval { $sub->(); 1 } if $sub;
     }
     unless ($ok) {
         my $err = $@;
